summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/knewaccountdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/knewaccountdlg.h')
-rw-r--r--kmymoney2/dialogs/knewaccountdlg.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/dialogs/knewaccountdlg.h b/kmymoney2/dialogs/knewaccountdlg.h
index a4ae636..807af7e 100644
--- a/kmymoney2/dialogs/knewaccountdlg.h
+++ b/kmymoney2/dialogs/knewaccountdlg.h
@@ -81,17 +81,17 @@ public:
* apply and will be handled by the dialog.
*
* @param account The original data to be used to create the account. In case
* of @p isEditing is false, the account id, the tqparent account id
* and the list of all child accounts will be cleared.
* @param isEditing If @p false, rules for new account creation apply.
* If @p true, rules for account editing apply
* @param categoryEditor If @p false, rules for asset/liability accounts apply.
* If @p true, rules for income/expense account apply.
* @param tqparent Pointer to tqparent object (passed to TQDialog). Default is 0.
* @param name Name of the object (passed to TQDialog). Default is 0.
* @param title Caption of the object (passed to TQDialog). Default is empty string.
*/
- KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, TQWidget *tqparent=0, const char *name=0, const TQString& title=TQString());
+ KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, TQWidget *parent=0, const char *name=0, const TQString& title=TQString());
/**
* This method returns the edited account object.
@@ -99,7 +99,7 @@ public:
const MyMoneyAccount& account(void);
/**
* This method returns the tqparent account of the edited account object.
*/
const MyMoneyAccount& parentAccount(void);
@@ -81,17 +81,17 @@ public:
*
* @param account The original data to be used to create the account. In case
- * of @p isEditing is false, the account id, the tqparent account id
+ * of @p isEditing is false, the account id, the parent account id
* and the list of all child accounts will be cleared.
* @param isEditing If @p false, rules for new account creation apply.
@@ -81,17 +81,17 @@ public:
* @param categoryEditor If @p false, rules for asset/liability accounts apply.
* If @p true, rules for income/expense account apply.
- * @param tqparent Pointer to tqparent object (passed to TQDialog). Default is 0.
+ * @param parent Pointer to parent object (passed to TQDialog). Default is 0.
* @param name Name of the object (passed to TQDialog). Default is 0.
* @param title Caption of the object (passed to TQDialog). Default is empty string.
@@ -99,7 +99,7 @@ public:
const MyMoneyAccount& account(void);
/**
- * This method returns the tqparent account of the edited account object.
+ * This method returns the parent account of the edited account object.
*/
const MyMoneyAccount& parentAccount(void);